import enum


__all__ = ["Frequency", "Voltage", "Current", "CurveState"]


class Frequency(enum.IntEnum):
    FREQUENCY_10HZ = 0
    FREQUENCY_100HZ = 1
    FREQUENCY_1KHZ = 2
    FREQUENCY_10KHZ = 3


FrequencyValues = {
    10.0: Frequency.FREQUENCY_10HZ,
    100.0: Frequency.FREQUENCY_100HZ,
    1000.0: Frequency.FREQUENCY_1KHZ,
    10000.0: Frequency.FREQUENCY_10KHZ}


class Voltage(enum.IntEnum):
    VOLTAGE_3_3V = 0
    VOLTAGE_5V = 1
    VOLTAGE_12V = 2


VoltageValues = {
    3.3: Voltage.VOLTAGE_3_3V,
    5.0: Voltage.VOLTAGE_5V,
    12.0: Voltage.VOLTAGE_12V}


class Current(enum.IntEnum):
    CURRENT_250UA = 0
    CURRENT_2_5MA = 1
    CURRENT_25MA = 2


class CurveState(enum.IntEnum):
    NORMAL = 0
    FROZEN = 1


class MeasureFlags(int):
    CURRENT_SENSE_MODE_ISOLATED = 0
    CURRENT_SENSE_MODE_250UA = 1
    CURRENT_SENSE_MODE_2M5A = 2
    CURRENT_SENSE_MODE_25MA = 3
    CURRENT_SENSE_MODE_BITS = 3

    @property
    def current_sense_mode_isolated(self) -> bool:
        return self & self.CURRENT_SENSE_MODE_BITS == self.CURRENT_SENSE_MODE_ISOLATED

    @property
    def current_sense_mode_250_ua(self) -> bool:
        return self & self.CURRENT_SENSE_MODE_BITS == self.CURRENT_SENSE_MODE_250UA

    @property
    def current_sense_mode_2_m5_a(self) -> bool:
        return self & self.CURRENT_SENSE_MODE_BITS == self.CURRENT_SENSE_MODE_2M5A

    @property
    def current_sense_mode_25_ma(self) -> bool:
        return self & self.CURRENT_SENSE_MODE_BITS == self.CURRENT_SENSE_MODE_25MA

    @property
    def current_sense_mode_bits(self) -> bool:
        return self & self.CURRENT_SENSE_MODE_BITS == self.CURRENT_SENSE_MODE_BITS